.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    border-width: 0;
}

.rating {
    position: relative;
    display: inline-flex;
}

.rating input {
    appearance: none;
    -webkit-appearance: none;
}

.space > :not([hidden]) ~ :not([hidden]) {
    margin-right: 0.25rem;
}

.rating .rating-hidden {
    width: 0.5rem;
    background-color: transparent;
    cursor: pointer;
}

.rating-disable {
    opacity: 0.3;
    filter: grayscale(100%);
}

.rating input + label {
    cursor: pointer;
}

/*.rating input + label, !* FOR REACTION SETTINGS *!*/
.rating input:checked ~ label,
.rating input[aria-checked=true] ~ label {
    opacity: 0.3;
}

.rating input:checked + label {
    opacity: 1;
}

